@@ -19,10 +19,11 @@
 #include <QFile>
 #include <QUrl>
 #include <kprotocolmanager.h>
+#include <KConfig>
+#include <KConfigGroup>
 #include <QDebug>
 #include <QtTest>
 #include <qstandardpaths.h>
-#include <kservice.h>
 
 // Tests both KProtocolInfo and KProtocolManager
 
@@ -30,16 +31,25 @@ class KProtocolInfoTest : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
+    void initTestCase();
 
     void testBasic();
     void testExtraFields();
     void testShowFilePreview();
     void testSlaveProtocol();
+    void testProxySettings_data();
+    void testProxySettings();
     void testCapabilities();
     void testProtocolForArchiveMimetype();
     void testHelperProtocols();
 };
 
+void KProtocolInfoTest::initTestCase()
+{
+    QString configFile = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + "/kioslaverc";
+    QFile::remove(configFile);
+}
+
 void KProtocolInfoTest::testBasic()
 {
     QVERIFY(KProtocolInfo::isKnownProtocol(QUrl("http:/")));
@@ -78,6 +88,7 @@ void KProtocolInfoTest::testSlaveProtocol()
     QString proxy;
     QString protocol = KProtocolManager::slaveProtocol(QUrl("http://bugs.kde.org"), proxy);
     QCOMPARE(protocol, QString::fromLatin1("http"));
+    QVERIFY(!KProtocolManager::useProxy());
 
     // Just to test it doesn't deadlock
     KProtocolManager::reparseConfiguration();
@@ -85,6 +96,36 @@ void KProtocolInfoTest::testSlaveProtocol()
     QCOMPARE(protocol, QString::fromLatin1("http"));
 }
 
+void KProtocolInfoTest::testProxySettings_data()
+{
+    QTest::addColumn<int>("proxyType");
+
+    // Just to test it doesn't deadlock (bug 346214)
+    QTest::newRow("manual") << static_cast<int>(KProtocolManager::ManualProxy);
+    QTest::newRow("wpad") << static_cast<int>(KProtocolManager::WPADProxy);
+    // Same for bug 350890
+    QTest::newRow("envvar") << static_cast<int>(KProtocolManager::EnvVarProxy);
+}
+
+void KProtocolInfoTest::testProxySettings()
+{
+    QFETCH(int, proxyType);
+    KConfig config("kioslaverc", KConfig::NoGlobals);
+    KConfigGroup cfg(&config, "Proxy Settings");
+    cfg.writeEntry("ProxyType", proxyType);
+    cfg.sync();
+    KProtocolManager::reparseConfiguration();
+    QString proxy;
+    QString protocol = KProtocolManager::slaveProtocol(QUrl("http://bugs.kde.org"), proxy);
+    QCOMPARE(protocol, QString::fromLatin1("http"));
+    QVERIFY(KProtocolManager::useProxy());
+
+    // restore
+    cfg.writeEntry("ProxyType", static_cast<int>(KProtocolManager::NoProxy));
+    cfg.sync();
+    KProtocolManager::reparseConfiguration();
+}
+
 void KProtocolInfoTest::testCapabilities()
 {
     QStringList capabilities = KProtocolInfo::capabilities("imap");
