@@ -24,6 +24,7 @@
 #include <stdio.h>
 
 #include <QtCore/QFile>
+#include <QtCore/QStandardPaths>
 #include <QtCore/QTimer>
 #include <QtCore/QProcess>
 
@@ -35,13 +36,12 @@
 #include <kpluginloader.h>
 
 #include "dataprotocol_p.h"
-#include "kservice.h"
 #include "connection_p.h"
 #include "commands_p.h"
 #include "connectionserver.h"
 #include "kioglobal_p.h"
 #include <kprotocolinfo.h>
-#include <config-kiocore.h> // CMAKE_INSTALL_PREFIX
+#include <config-kiocore.h> // CMAKE_INSTALL_FULL_LIBEXECDIR_KF5
 
 #include "slaveinterface_p.h"
 
@@ -74,6 +74,35 @@ static org::kde::KSlaveLauncher *klauncher()
     return s_kslaveLauncher.localData();
 }
 
+// In such case we start the slave via QProcess.
+// It's possible to force this by setting the env. variable
+// KDE_FORK_SLAVES, Clearcase seems to require this.
+static QBasicAtomicInt bForkSlaves = Q_BASIC_ATOMIC_INITIALIZER(-1);
+
+static bool forkSlaves()
+{
+    // In such case we start the slave via QProcess.
+    // It's possible to force this by setting the env. variable
+    // KDE_FORK_SLAVES, Clearcase seems to require this.
+    if (bForkSlaves.load() == -1) {
+        bool fork = qEnvironmentVariableIsSet("KDE_FORK_SLAVES");
+
+#ifdef Q_OS_UNIX
+        // fallback: if there's an klauncher process owned by a different user: still fork
+        if (!fork) {
+            // check the UID of klauncher
+            QDBusReply<uint> reply = QDBusConnection::sessionBus().interface()->serviceUid(klauncher()->service());
+            if (reply.isValid() && getuid() != reply) {
+                fork = true;
+            }
+        }
+#endif
+
+        bForkSlaves.testAndSetRelaxed(-1, fork ? 1 : 0);
+    }
+    return bForkSlaves.load() == 1;
+}
+
 namespace KIO
 {
 
@@ -98,7 +127,7 @@ public:
         m_idleSince = QDateTime();
         slaveconnserver->listenForRemote();
         if (!slaveconnserver->isListening()) {
-            qWarning() << "Connection server not listening, could not connect";
+            qWarning() << "KIO Connection server not listening, could not connect";
         }
     }
     ~SlavePrivate()
@@ -427,27 +456,7 @@ Slave *Slave::createSlave(const QString &protocol, const QUrl &url, int &error,
     Slave *slave = new Slave(protocol);
     QUrl slaveAddress = slave->d_func()->slaveconnserver->address();
 
-#ifdef Q_OS_UNIX
-    // In such case we start the slave via QProcess.
-    // It's possible to force this by setting the env. variable
-    // KDE_FORK_SLAVES, Clearcase seems to require this.
-    static QBasicAtomicInt bForkSlaves = Q_BASIC_ATOMIC_INITIALIZER(-1);
-
-    if (bForkSlaves.load() == -1) {
-        bool fork = !qgetenv("KDE_FORK_SLAVES").isEmpty();
-
-        if (!fork) {
-            // check the UID of klauncher
-            QDBusReply<uint> reply = QDBusConnection::sessionBus().interface()->serviceUid(klauncher()->service());
-            if (reply.isValid() && getuid() != reply) {
-                fork = true;
-            }
-        }
-
-        bForkSlaves.testAndSetRelaxed(-1, fork ? 1 : 0);
-    }
-
-    if (bForkSlaves.load() == 1) {
+    if (forkSlaves() == 1) {
         QString _name = KProtocolInfo::exec(protocol);
         if (_name.isEmpty()) {
             error_text = i18n("Unknown protocol '%1'.", protocol);
@@ -469,19 +478,19 @@ Slave *Slave::createSlave(const QString &protocol, const QUrl &url, int &error,
         const QStringList args = QStringList() << lib_path << protocol << "" << slaveAddress.toString();
         //qDebug() << "kioslave" << ", " << lib_path << ", " << protocol << ", " << QString() << ", " << slaveAddress;
 
-        const QString kioslave = CMAKE_INSTALL_PREFIX "/" KF5_LIBEXEC_INSTALL_DIR "/kioslave";
-        if (kioslave.isEmpty()) {
-            error_text = i18n("Can not find 'kioslave' executable");
+        const QLatin1String libExecDir(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5);
+        const QString kioslaveExecutable = QStandardPaths::findExecutable("kioslave", {libExecDir});
+        if (kioslaveExecutable.isEmpty()) {
+            error_text = i18n("Can not find 'kioslave' executable at '%1'", libExecDir);
             error = KIO::ERR_CANNOT_LAUNCH_PROCESS;
             delete slave;
             return 0;
 
         }
-        QProcess::startDetached(kioslave, args);
+        QProcess::startDetached(kioslaveExecutable, args);
 
         return slave;
     }
-#endif
 
     QString errorStr;
     QDBusReply<int> reply = klauncher()->requestSlave(protocol, url.host(), slaveAddress.toString(), errorStr);
@@ -529,6 +538,10 @@ Slave *Slave::holdSlave(const QString &protocol, const QUrl &url)
 
 bool Slave::checkForHeldSlave(const QUrl &url)
 {
+    if (forkSlaves()) {
+        return false;
+    }
+
     return klauncher()->checkForHeldSlave(url.toString());
 }
 
