@@ -897,16 +897,14 @@ void KFileWidget::slotOk()
             }
 
             // now recalculate all paths for them being relative in base of the top most url
+            QStringList stringList;
             for (int i = 0; i < locationEditCurrentTextList.count(); ++i) {
-                locationEditCurrentTextList[i] = QUrl(relativePathOrUrl(topMostUrl, locationEditCurrentTextList[i]));
+                Q_ASSERT(topMostUrl.isParentOf(locationEditCurrentTextList[i]));
+                stringList << relativePathOrUrl(topMostUrl, locationEditCurrentTextList[i]);
             }
 
             d->ops->setUrl(topMostUrl, true);
             const bool signalsBlocked = d->locationEdit->lineEdit()->blockSignals(true);
-            QStringList stringList;
-            foreach (const QUrl &url, locationEditCurrentTextList) {
-                stringList << url.toDisplayString();
-            }
             d->locationEdit->lineEdit()->setText(QString("\"%1\"").arg(stringList.join("\" \"")));
             d->locationEdit->lineEdit()->blockSignals(signalsBlocked);
 
@@ -1029,6 +1027,9 @@ void KFileWidget::slotOk()
             d->locationEdit->lineEdit()->setText(QString());
             d->locationEdit->lineEdit()->blockSignals(signalsBlocked);
             return;
+        } else if (res && onlyDirectoryMode && !statJob->statResult().isDir()) {
+            // if we are given a file when on directory only mode, reject it
+            return;
         } else if (!(mode & KFile::ExistingOnly) || res) {
             // if we don't care about ExistingOnly flag, add the file even if
             // it doesn't exist. If we care about it, don't add it to the list
