@@ -34,21 +34,12 @@
 #include <kusertimestamp.h>
 #include <klocalizedstring.h>
 
-#include <kpluginfactory.h>
-#include <kpluginloader.h>
-
 #include <QPushButton>
 #include <QTimer>
 #include <ctime>
 
 static QLoggingCategory category("org.kde.kio.kpasswdserver");
 
-
-K_PLUGIN_FACTORY(KPasswdServerFactory,
-                 registerPlugin<KPasswdServer>();
-    )
-K_EXPORT_PLUGIN(KPasswdServerFactory("kpasswdserver"))
-
 #define AUTHINFO_EXTRAFIELD_DOMAIN QLatin1String("domain")
 #define AUTHINFO_EXTRAFIELD_ANONYMOUS QLatin1String("anonymous")
 #define AUTHINFO_EXTRAFIELD_BYPASS_CACHE_AND_KWALLET QLatin1String("bypass-cache-and-kwallet")
@@ -83,8 +74,6 @@ KPasswdServer::KPasswdServer(QObject* parent, const QList<QVariant>&)
     m_walletDisabled = false;
 
     KPasswdServerAdaptor *adaptor = new KPasswdServerAdaptor(this);
-    // register separately from kded
-    QDBusConnection::sessionBus().registerService("org.kde.kpasswdserver");
     // connect signals to the adaptor
     connect(this,
             SIGNAL(checkAuthInfoAsyncResult(qlonglong,qlonglong,KIO::AuthInfo)),
@@ -225,8 +214,8 @@ bool KPasswdServer::hasPendingQuery(const QString &key, const KIO::AuthInfo &inf
     return false;
 }
 
-QByteArray
-KPasswdServer::checkAuthInfo(const QByteArray &data, qlonglong windowId, qlonglong usertime)
+// deprecated method, not used anymore. TODO KF6: REMOVE
+QByteArray KPasswdServer::checkAuthInfo(const QByteArray &data, qlonglong windowId, qlonglong usertime)
 {
     KIO::AuthInfo info;
     QDataStream stream(data);
@@ -256,6 +245,7 @@ KPasswdServer::checkAuthInfo(const QByteArray &data, qlonglong windowId, qlonglo
     if (!result || result->isCanceled)
     {
         if (!result &&
+            !m_walletDisabled &&
             (info.username.isEmpty() || info.password.isEmpty()) &&
             !KWallet::Wallet::keyDoesNotExist(KWallet::Wallet::NetworkWallet(),
                                               KWallet::Wallet::PasswordFolder(),
@@ -317,6 +307,7 @@ qlonglong KPasswdServer::checkAuthInfoAsync(KIO::AuthInfo info, qlonglong window
     if (!result || result->isCanceled)
     {
         if (!result &&
+            !m_walletDisabled &&
             (info.username.isEmpty() || info.password.isEmpty()) &&
             !KWallet::Wallet::keyDoesNotExist(KWallet::Wallet::NetworkWallet(),
                                               KWallet::Wallet::PasswordFolder(),
@@ -344,9 +335,9 @@ qlonglong KPasswdServer::checkAuthInfoAsync(KIO::AuthInfo info, qlonglong window
     return 0; // ignored
 }
 
-QByteArray
-KPasswdServer::queryAuthInfo(const QByteArray &data, const QString &errorMsg,
-                             qlonglong windowId, qlonglong seqNr, qlonglong usertime)
+// deprecated method, not used anymore. TODO KF6: REMOVE
+QByteArray KPasswdServer::queryAuthInfo(const QByteArray &data, const QString &errorMsg,
+                                        qlonglong windowId, qlonglong seqNr, qlonglong usertime)
 {
     KIO::AuthInfo info;
     QDataStream stream(data);
@@ -439,7 +430,7 @@ KPasswdServer::addAuthInfo(const KIO::AuthInfo &info, qlonglong windowId)
         // Since storing the password in the wallet succeeded, make sure the
         // password information is stored in memory only for the duration the
         // windows associated with it are still around.
-        AuthInfo authToken (info);
+        KIO::AuthInfo authToken (info);
         authToken.keepPassword = false;
         addAuthInfoItem(key, authToken, windowId, m_seqNr, false);
         return;
@@ -448,8 +439,8 @@ KPasswdServer::addAuthInfo(const KIO::AuthInfo &info, qlonglong windowId)
     addAuthInfoItem(key, info, windowId, m_seqNr, false);
 }
 
-void
-KPasswdServer::addAuthInfo(const QByteArray &data, qlonglong windowId)
+// deprecated method, not used anymore. TODO KF6: REMOVE
+void KPasswdServer::addAuthInfo(const QByteArray &data, qlonglong windowId)
 {
     KIO::AuthInfo info;
     QDataStream stream(data);
@@ -563,7 +554,6 @@ KPasswdServer::processRequest()
             dlg->setObjectName("warningOKCancel");
             QDialogButtonBox* buttonBox = new QDialogButtonBox(QDialogButtonBox::Yes|QDialogButtonBox::Cancel);
             buttonBox->button(QDialogButtonBox::Yes)->setText(i18nc("@action:button filter-continue", "Retry"));
-            connect(buttonBox, SIGNAL(accepted()), SLOT(accept()));
 
             KMessageBox::createKMessageBox(dlg, buttonBox, QMessageBox::Warning, prompt,
                                            QStringList(), QString(), 0,
@@ -807,6 +797,7 @@ void KPasswdServer::showPasswordDialog (KPasswdServer::Request* request)
 
     if ( !bypassCacheAndKWallet
         && ( username.isEmpty() || password.isEmpty() )
+        && !m_walletDisabled
         && !KWallet::Wallet::keyDoesNotExist(KWallet::Wallet::NetworkWallet(), KWallet::Wallet::PasswordFolder(), makeWalletKey( request->key, info.realmValue )) )
     {
         // no login+pass provided, check if kwallet has one
@@ -954,7 +945,7 @@ void KPasswdServer::sendResponse (KPasswdServer::Request* request)
        QTimer::singleShot(0, this, SLOT(processRequest()));
 }
 
-void KPasswdServer::passwordDialogDone (int result)
+void KPasswdServer::passwordDialogDone(int result)
 {
     KPasswordDialog* dlg = qobject_cast<KPasswordDialog*>(sender());
     Q_ASSERT(dlg);
@@ -969,7 +960,6 @@ void KPasswdServer::passwordDialogDone (int result)
         qCDebug(category) << "dialog result=" << result << ", bypassCacheAndKWallet?" << bypassCacheAndKWallet;
         if (dlg && result == QDialog::Accepted) {
             Q_ASSERT(dlg);
-            const QString oldUsername (info.username);
             info.username = dlg->username();
             info.password = dlg->password();
             info.keepPassword = dlg->keepPassword();
@@ -1027,7 +1017,7 @@ void KPasswdServer::passwordDialogDone (int result)
     dlg->deleteLater();
 }
 
-void KPasswdServer::retryDialogDone (int result)
+void KPasswdServer::retryDialogDone(int result)
 {
     QDialog* dlg = qobject_cast<QDialog*>(sender());
     Q_ASSERT(dlg);
@@ -1036,7 +1026,7 @@ void KPasswdServer::retryDialogDone (int result)
     Q_ASSERT(request);
 
     if (request) {
-        if (result == QDialog::Accepted) {
+        if (result == QDialogButtonBox::Yes) {
             showPasswordDialog(request.take());
         } else {
             // NOTE: If the user simply cancels the retry dialog, we remove the
@@ -1101,5 +1091,3 @@ void KPasswdServer::updateCachedRequestKey (QList<KPasswdServer::Request*>& list
     }
 }
 
-
-#include "kpasswdserver.moc"
